from django import forms
from django.utils.translation import gettext as _

from ajax_select.fields import AutoCompleteField, AutoCompleteWidget
from crispy_forms.helper import FormHelper
from crispy_forms.layout import HTML, Div, Layout


class HIDAutoCompleteField(AutoCompleteField):
    pass


class HIDAutoCompleteWidget(AutoCompleteWidget):
    pass


class FiltersForm(forms.Form):
    tags = HIDAutoCompleteField(
        'tags',
        required=False,
        help_text=None,
        label=_("TAGS"),
        widget=HIDAutoCompleteWidget(
            'tags',
            attrs={'placeholder': _('All Tags'), 'class': 'form-control'}
        )
    )

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.helper = FormHelper(self)
        self.helper.form_action = ''
        self.helper.form_method = 'GET'
        self.helper.layout = Layout(
            Div(
                Div(
                    HTML("{% include 'hid/tabs/filters/time_range.html' %}"),
                    HTML("{% include 'hid/tabs/filters/category.html' %}"),
                    'tags',
                    HTML("{% include 'hid/tabs/filters/gender.html' %}"),
                    HTML(
                        "{% include 'hid/tabs/filters/feedback_type.html' %}"
                    ),
                    HTML("{% include 'hid/tabs/filters/age_range.html' %}"),
                    HTML("{% include 'hid/tabs/filters/location.html' %}"),
                    HTML(
                        "{% include 'hid/tabs/filters/sub_location.html' %}"
                    ),
                    HTML("{% include 'hid/tabs/filters/enumerator.html' %}"),
                    HTML(
                        "{% include 'hid/tabs/filters/"
                        "collection_type.html' %}"
                    ),
                    HTML("{% include 'hid/tabs/filters/search.html' %}"),
                    css_class='filters form-group'
                ),
                Div(
                    HTML(
                        "{% load bootstrap3 %}"
                        "{% bootstrap_button _('Apply filters') "
                        "name='button-apply' value='apply' "
                        "button_class='btn btn-default btn-md' %}"
                    ),
                    HTML(
                        "{% load bootstrap3 %}"
                        "{% bootstrap_button _('Reset filters') "
                        "name='button-clear' value='clear' "
                        "button_class='btn btn-link' %}"
                    ),
                    css_class='filter-buttons'
                ),
                css_class='row filter-container'
            )
        )
