import pytest

from hid.lookups import TagsLookup
from taxonomies.tests.factories import TaxonomyFactory, TermFactory


@pytest.mark.django_db
def test_lookup_query_only_contains_tags():
    tags_tax = TaxonomyFactory(name='tags')
    other_tax = TaxonomyFactory()

    expected_terms = [TermFactory(name='hello', taxonomy=tags_tax)]
    TermFactory(name='hello bye', taxonomy=other_tax)

    tags = TagsLookup()
    actual_terms = list(tags.get_query('hello', None))

    assert expected_terms == actual_terms


@pytest.mark.django_db
def test_lookup_query_only_contains_items_beginning_with_query_string():
    query_string = 'Hello'
    tags_tax = TaxonomyFactory(name='tags')

    expected_terms = [TermFactory(name=query_string, taxonomy=tags_tax)]
    TermFactory(name=f'bye {query_string}', taxonomy=tags_tax)

    tags = TagsLookup()
    actual_terms = list(tags.get_query(query_string, None))

    assert expected_terms == actual_terms


@pytest.mark.django_db
def test_lookup_query_is_case_insensitive():
    query_string = 'Hello'
    tags_tax = TaxonomyFactory(name='tags')

    expected_terms = [TermFactory(name='hello', taxonomy=tags_tax)]

    tags = TagsLookup()
    actual_terms = list(tags.get_query(query_string, None))

    assert expected_terms == actual_terms


def test_only_term_name_displayed_in_dropdown():
    term = TermFactory.build(name='hello')

    tags = TagsLookup()
    result = tags.format_match(term)

    assert 'hello' == result


def test_only_term_name_displayed_in_text_box():
    term = TermFactory.build(name='hello')

    tags = TagsLookup()
    tags.get_query()
    result = tags.get_result(term)

    assert 'hello' == result
